@@ -14,15 +14,11 @@ gettext.install("blueberry", "/usr/share/locale")
 
 class BluetoothTray(Gtk.Application):
     def __init__(self):
-        super(BluetoothTray, self).__init__(register_session=True)
+        super(BluetoothTray, self).__init__(register_session=True, application_id="org.linuxmint.blueberry.tray")
 
     def do_activate(self):
         self.hold()
 
-    def do_shutdown(self):
-        self.terminate()
-        Gtk.Application.do_shutdown(self)
-
     def do_startup(self):
         Gtk.Application.do_startup(self)
 
@@ -31,7 +27,7 @@ class BluetoothTray(Gtk.Application):
             debug = True
 
         self.rfkill = rfkillMagic.Interface(self.update_icon_callback, debug)
-        self.settings = Gio.Settings("org.blueberry")
+        self.settings = Gio.Settings(schema="org.blueberry")
         self.settings.connect("changed::tray-enabled", self.on_settings_changed_cb)
 
         # If we have no adapter, or disabled tray, end early
@@ -142,8 +138,7 @@ class BluetoothTray(Gtk.Application):
         subprocess.Popen(["blueberry"])
 
     def terminate(self, window = None, data = None):
-        self.rfkill.terminate()
-        self.release()
+        self.quit()
 
 if __name__ == "__main__":
     BluetoothTray().run()
